Learn R Programming

mgc (version 2.0.2)

discr.rdf: Reliability Density Function

Description

A function for computing the reliability density function of a dataset.

Usage

discr.rdf(X, ids)

Arguments

X

[n, n] a distance matrix for n samples.

ids

[n] a vector containing the label ids for each sample.

Value

[n] vector of the reliability per sample.