the scaling for the signal dimension. Defaults to 10.
non.scale
the scaling for the non-signal dimensions. Defaults to 1.
mean.scale
whether the magnitude of the difference in the means between the two classes.
If a mean scale is requested, d should be at least > K.
rotate
whether to apply a random rotation. Defaults to TRUE.
class.equal
whether the number of samples/class should be equal, with each
class having a prior of 1/K, or inequal, in which each class obtains a prior
of k/sum(K) for k=1:K. Defaults to TRUE.
ind
whether to sample x and y independently. Defaults to FALSE.