A function to simulate data with the same mean that spreads as class id increases.
Usage
discr.sims.fat_tails(
n,
d,
K,
signal.scale = 1,
rotate = FALSE,
class.equal = TRUE,
ind = FALSE
)
Arguments
n
the number of samples.
d
the number of dimensions.
K
the number of classes in the dataset.
signal.scale
the scaling for the signal dimension. Defaults to 1.
rotate
whether to apply a random rotation. Defaults to TRUE.
class.equal
whether the number of samples/class should be equal, with each
class having a prior of 1/K, or inequal, in which each class obtains a prior
of k/sum(K) for k=1:K. Defaults to TRUE.
ind
whether to sample x and y independently. Defaults to FALSE.