A function to simulate data with the same mean with radial symmetry as class id increases.
Usage
discr.sims.radial(
n,
d,
K,
er.scale = 0.1,
r = 1,
class.equal = TRUE,
ind = FALSE
)
Arguments
n
the number of samples.
d
the number of dimensions.
K
the number of classes in the dataset.
er.scale
the scaling for the error of the samples. Defaults to 0.1.
r
the radial spacing between each class. Defaults to 1.
class.equal
whether the number of samples/class should be equal, with each
class having a prior of 1/K, or inequal, in which each class obtains a prior
of k/sum(K) for k=1:K. Defaults to TRUE.
ind
whether to sample x and y independently. Defaults to FALSE.