gen.x.unif: A helper function to generate n samples of a d-dimensional uniform vector.
Description
A helper function to generate n samples of a d-dimensional uniform vector.
Usage
gen.x.unif(n, d, a = -1, b = 1)
Arguments
d
the number of dimensions.
x
[n, d] the simulated data matrix.