Transform the distance matrices, with column-wise ranking if needed.
Usage
mgc.dist.xfm(X, Y, option = "mgc", optionRk = TRUE)
Arguments
X
[nxn] is a distance matrix
Y
[nxn] is a second distance matrix
option
is a string that specifies which global correlation to build up-on. Defaults to mgc.
'mgc'
use the MGC global correlation.
'dcor'
use the dcor global correlation.
'mantel'
use the mantel global correlation.
'rank'
use the rank global correlation.
optionRk
is a string that specifies whether ranking within column is computed or not. If option='rank', ranking will be performed regardless of the value specified by optionRk. Defaults to TRUE.