powered by
A function for computing the reliability density function of a dataset.
discr.rdf(X, ids)
[n, n] a distance matrix for n samples.
[n, n]
[n] a vector containing the label ids for each sample.
[n]
[n] vector of the reliability per sample.